/**
 * @file
 * Provides AJAX functionality for Ultimenu blocks.
 */

(function ($, Drupal, drupalSettings, _win) {

  'use strict';

  var _name = 'ultiajax';
  var _idOnce = _name;
  var _mounted = _name + '--on';
  var _element = '[data-' + _name + ']:not(.' + _mounted + ')';
  var _ajaxTrigger = '[data-' + _name + '-trigger]';

  Drupal.ultimenu = Drupal.ultimenu || {};

  /**
   * Ultimenu utility functions for the ajaxified links, including main menu.
   *
   * @param {HTMLElement} elm
   *   The ultimenu HTML element.
   */
  function doUltimenuAjax(elm) {
    var me = Drupal.ultimenu;

    if (drupalSettings.ultimenu && drupalSettings.ultimenu.ajaxmw && _win.matchMedia) {
      var mw = _win.matchMedia('(max-device-width: ' + drupalSettings.ultimenu.ajaxmw + ')');
      if (mw.matches) {
        var links = $.findAll(elm, _ajaxTrigger);
        if (links.length) {
          // Load all AJAX contents if so configured.
          $.each(links, me.executeAjax.bind(me));

          return;
        }
      }
    }

    // Regular mobie/ desktop AJAX.
    $.on(elm, 'mouseover click', _ajaxTrigger, me.triggerAjax.bind(me));
    $.addClass(elm, _mounted);
  }

  /**
   * Attaches Ultimenu behavior to HTML element [data-ultiajax].
   *
   * @type {Drupal~behavior}
   */
  Drupal.behaviors.ultimenuAjax = {
    attach: function (context) {
      $.once(doUltimenuAjax, _idOnce, _element, context);
    },
    detach: function (context, setting, trigger) {
      if (trigger === 'unload') {
        $.once.removeSafely(_idOnce, _element, context);
      }
    }
  };

})(dBlazy, Drupal, drupalSettings, this);
