/**
 * @file
 * Provides mobile toggler for the the Ultimenu main block.
 */

(function ($, Drupal, drupalSettings, _win, _doc) {

  'use strict';

  var _name = 'ultimenu';
  var _idOnce = _name;
  var _mounted = _name + '--on';
  var _canvas = 'is-' + _name + '-canvas';
  var _backdrop = _canvas + '-backdrop';
  var _hamburger = '[data-' + _name + '-button]';
  var _selector = '[data-' + _name + ']';
  var _element = _selector + ':not(.' + _mounted + ')';

  Drupal.ultimenu = Drupal.ultimenu || {};

  /**
   * Ultimenu utility functions for the main menu only.
   *
   * @param {HTMLElement} elm
   *   The ultimenu HTML element.
   */
  function doUltimenu(elm) {
    var me = Drupal.ultimenu;

    // Applies to other Ultimenus.
    $.on(elm, 'click', '.caret', me.doClickCaret.bind(me));

    $.addClass(elm, _mounted);
  }

  /**
   * Attaches Ultimenu behavior to HTML element [data-ultimenu].
   *
   * @type {Drupal~behavior}
   */
  Drupal.behaviors.ultimenu = {
    attach: function (context) {

      var me = Drupal.ultimenu;
      var $body = _doc.body;
      var ctx = $.context(context, _selector);
      var items = $.findAll(ctx, _element);

      if (items.length) {
        me.prepare();

        // @todo use core/once when min D9.2.
        $.once(doUltimenu, _idOnce, _element, context);

        // Reacts on clicking Ultimenu hamburger button.
        $.on($body, 'click', _hamburger, me.doClickHamburger.bind(me));
        $.on($body, 'click', '.' + _backdrop, me.triggerClickHamburger.bind(me));

        // Reacts on resizing Ultimenu.
        me.onResize(me.doResizeMain.bind(me))();
      }
    },
    detach: function (context, setting, trigger) {
      if (trigger === 'unload') {
        $.once.removeSafely(_idOnce, _element, context);
      }
    }
  };

})(dBlazy, Drupal, drupalSettings, this, this.document);
